// Problem : D (Spring tournament 2007)
// Checker : Igor V. Burago

{$apptype console}

{$iochecks on}
{$rangechecks on}
{$overflowchecks on}
{$debuginfo off}
{$optimization on}

uses
  SysUtils, Math;

type
  TExitCode = (ecOK, ecWrongAnswer, ecPresentationError, ecUnhandledError);
  TYesNoString = (ynNo, ynYes);

var
  FIn, FOut, FAns: TextFile;

procedure Done(const Msg: string; const ExitCode: TExitCode);
begin
  write(Msg);
  try CloseFile(FIn); except { Do Nothing } end;
  try CloseFile(FOut); except { Do Nothing } end;
  try CloseFile(FAns); except { Do Nothing } end;
  Halt(Ord(ExitCode));
end;

const
  ValidAnswer: array [TYesNoString] of string = ('NO', 'YES');
  ValidAnswerLength = 3;
  FileOpenError = '%s file cannot be opened';

var  
  StrOut, StrAns, Tmp: string;
  N, K, NumsCount, Num, Sum: integer;
  PreSum: int64;

begin
  try
    AssignFile(FIn, ParamStr(1));
    Reset(FIn);
  except
    Done(Format(FileOpenError, ['Input']), ecUnhandledError);
  end;
  try
    AssignFile(FOut, ParamStr(2));
    Reset(FOut);
  except
    Done(Format(FileOpenError, ['Output']), ecPresentationError);
  end;
  try
    AssignFile(FAns, ParamStr(3));
    Reset(FAns);
  except
    Done(Format(FileOpenError, ['Answer']), ecUnhandledError);
  end;

  try
    read(FIn, N, K);
  except
    Done('Error while reading input file', ecUnhandledError);
  end;

  try
    if SeekEof(FOut) then
      Done('No data in output file', ecPresentationError);
    read(FOut, StrOut);
  except
    Done('Presentation error', ecPresentationError);
  end;

  try
    read(FAns, StrAns);
  except
    Done('Error while reading answer file', ecUnhandledError);
  end;

  if (StrOut <> ValidAnswer[ynNo]) and (StrOut <> ValidAnswer[ynYes]) then begin
    Tmp := Format('Unknown string: %0.3s', [StrOut]);
    if Length(StrOut) > ValidAnswerLength then
      Tmp := Tmp + '...';
    Done(Tmp, ecPresentationError);
  end;

  if (StrOut <> StrAns) then
    Done(Format('%s instead of %s', [StrOut, StrAns]), ecWrongAnswer);

  try
    if StrOut = ValidAnswer[ynNo] then begin
      if not SeekEof(FOut) then
        Done('No suitcases needed: the answer is NO', ecPresentationError);
    end else begin
      Sum := 0;
      NumsCount := 0;
      while not SeekEof(FOut) do begin
        read(FOut, Num);
        if Num <= 0 then
          Done(Format('Negative or zero number: %d <= 0', [Num]), ecWrongAnswer);
        PreSum := int64(Sum) + int64(Num) * Num;
        if PreSum > MaxInt then
          Done('Sum of squares is too big', ecWrongAnswer);
        Inc(Sum, Num * Num);
        Inc(NumsCount);
        if not SeekEof(FOut) and (NumsCount > K) then
          Done('Too many suitcases or extra data', ecPresentationError);
      end;
      if NumsCount = 0 then
        Done('No suitcases found', ecPresentationError);
      if Sum <> N then
        Done(Format('Wrong answer: %d <> %d', [Sum, N]), ecWrongAnswer);
    end;
    if not SeekEof(FOut) then
      Done('Extra data in output file', ecPresentationError);
  except
    on E: EIntOverflow do
      Done('Sum of squares is too big', ecWrongAnswer);
    on E: Exception do
      Done('Presentation error', ecPresentationError);
  end;

  Done('OK', ecOK);
end.